@@ -107,7 +107,7 @@ def test_text_emit_warnings(app, warning):
     # test warnings in translation
     warnings = getwarning(warning)
     warning_expr = ('.*/warnings.txt:4:<translated>:1: '
-                   'WARNING: Inline literal start-string without end-string.\n')
+                    'WARNING: Inline literal start-string without end-string.\n')
     assert_re_search(warning_expr, warnings)
 
 
@@ -885,8 +885,8 @@ def test_xml_keep_external_links(app):
     assert_elem(
         para1[0],
         ['LINK TO', 'external2', 'AND', 'external1', '.'],
-        ['http://example.com/external2',
-         'http://example.com/external1'])
+        ['https://www.google.com/external2',
+         'https://www.google.com/external1'])
     assert_elem(
         para1[1],
         ['LINK TO', 'THE PYTHON SITE', 'AND', 'THE SPHINX SITE', '.'],
